-- Alle Tabellen in einer Datenbank dbsFluege auf dem Microsoft SQL-Server erstellen.
go


use dbsFluege
go


drop table dbo.tblFlugbuchung
drop table dbo.tblMitarbeiter
drop table dbo.tblFlug
drop table dbo.tblFlughafen
drop table dbo.tblFluggesellschaft
go


create table dbo.tblFlughafen
(
	FlughafenID	int not null
		constraint PK_tblFlughafen primary key,
	FlughafenName nvarchar(128) not null
)
go

create table dbo.tblFluggesellschaft
(
	FluggesellschaftID int not null
		constraint PK_tblFluggesellschaft primary key,
	FluggesellschaftName nvarchar(128) not null
)
go

create table dbo.tblFlug
(
	FlugID int not null
		identity(1, 1)
		constraint PK_tblFlug primary key,
	AbflugDatum datetime not null,
	AbflugZeit datetime not null,
	AnkunftZeit datetime not null,
	FluggesellschaftID int not null
		constraint FK_tblFlug_FluggesellschaftID
		foreign key references dbo.tblFluggesellschaft(FluggesellschaftID),
	Flugnummer nvarchar(7) not null,
	AbflugFlughafenID int not null
		constraint FK_tblFlug_AbflugFlughafenID
		foreign key references dbo.tblFlughafen(FlughafenID),
	AnkunftFlughafenID int not null
		constraint FK_tblFlug_AnkunftFlughafenID
		foreign key references dbo.tblFlughafen(FlughafenID)
)
go

create table dbo.tblMitarbeiter
(
	MitarbeiterID int not null
		identity(1, 1)
		constraint PK_tblMitarbeiter primary key,
	Nachname nvarchar(32) not null,
	Vorname nvarchar(32) null,
	Geschlecht	char(1) not null
		constraint CK_tblMitarbeiter_Geschlecht
			check(Geschlecht = 'M' or Geschlecht = 'W'),
	Geburtsdatum datetime null,
	Foto image null
)
go

create table dbo.tblFlugbuchung
(
	FlugbuchungID int not null
		identity(1, 1)
		constraint PK_tblFlugbuchung primary key,
	FlugID int not null
		constraint FK_tblFlugbuchung_FlugID
		foreign key references dbo.tblFlug(FlugID),
	MitarbeiterID int not null
		constraint FK_tblFlugbuchung_MitarbeiterID
		foreign key references dbo.tblMitarbeiter(MitarbeiterID),
	TicketBuchungsCode	nvarchar(32) null,
	Kosten money null,
	PrivaterFlug bit not null
		constraint DF_tblFlugbuchung_PrivaterFlug
			default (0)
)
go
